========
prakriya
========


.. image:: https://img.shields.io/pypi/v/prakriya.svg
        :target: https://pypi.python.org/pypi/prakriya

.. image:: https://img.shields.io/travis/drdhaval2785/python-prakriya.svg
        :target: https://travis-ci.org/drdhaval2785/python-prakriya

.. image:: https://readthedocs.org/projects/prakriya/badge/?version=latest
        :target: https://prakriya.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/drdhaval2785/python-prakriya/badge.svg?branch=master
     :target: https://coveralls.io/github/drdhaval2785/python-prakriya?branch=master
     :alt: Code coverage

.. image:: https://img.shields.io/badge/Donate-PayPal-green.svg
     :target: https://www.paypal.me/drdhaval2785/500inr
     :alt: Paypal

prakriya is a package to derive information about given Sanskrit verb form.


* Free software: GNU General Public License v3
* Documentation: https://prakriya.readthedocs.io.


Features
--------

1. Provides step by step derivation of certain tiNanta forms based on Panini's grammar of Sanskrit, using a ready database of prakriyas and sutras.
2. Supports various transliteration as input and output.
3. Also provides a commandline tool.


Support
-------
1. You can help development of code by testing and bug report.
2. You can contribute monetarily at the following link.

.. image:: https://img.shields.io/badge/Donate-PayPal-green.svg
     :target: https://www.paypal.me/drdhaval2785/500inr
     :alt: Paypal


Credits
---------

1. This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

2. This package uses indic-transliteration_ package.

.. _indic-transliteration: https://pypi.python.org/pypi/indic-transliteration
